Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/castep_linter/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src/castep_linter/error_logging/__init__.py | 2 | 0 | 0 | 0 | 0 | 100%
src/castep_linter/error_logging/error_types.py | 56 | 19 | 0 | 14 | 1 | 63%
src/castep_linter/error_logging/logger.py | 28 | 9 | 0 | 10 | 0 | 55%
src/castep_linter/error_logging/xml_writer.py | 16 | 11 | 0 | 6 | 0 | 23%
src/castep_linter/fortran/__init__.py | 3 | 0 | 0 | 0 | 0 | 100%
src/castep_linter/fortran/argument_parser.py | 39 | 4 | 0 | 16 | 2 | 89%
src/castep_linter/fortran/call_expression.py | 24 | 5 | 0 | 0 | 0 | 79%
src/castep_linter/fortran/fortran_node.py | 75 | 7 | 0 | 22 | 4 | 89%
src/castep_linter/fortran/fortran_statement.py | 10 | 2 | 0 | 3 | 2 | 69%
src/castep_linter/fortran/identifier.py | 20 | 0 | 0 | 6 | 0 | 100%
src/castep_linter/fortran/node_type_err.py | 1 | 0 | 0 | 0 | 0 | 100%
src/castep_linter/fortran/parser.py | 27 | 0 | 0 | 12 | 0 | 100%
src/castep_linter/fortran/variable_declaration.py | 53 | 0 | 0 | 8 | 0 | 100%
src/castep_linter/scan_files.py | 57 | 36 | 0 | 19 | 0 | 36%
src/castep_linter/tests/__init__.py | 6 | 0 | 0 | 0 | 0 | 100%
src/castep_linter/tests/allocate_stat_checked.py | 36 | 4 | 0 | 14 | 1 | 90%
src/castep_linter/tests/castep_identifiers.py | 11 | 0 | 0 | 0 | 0 | 100%
src/castep_linter/tests/complex_has_dp.py | 17 | 0 | 0 | 6 | 0 | 100%
src/castep_linter/tests/has_trace_entry_exit.py | 55 | 4 | 0 | 34 | 2 | 93%
src/castep_linter/tests/number_literal_correct_kind.py | 20 | 2 | 0 | 14 | 1 | 91%
src/castep_linter/tests/real_declaration_has_dp.py | 23 | 0 | 0 | 10 | 0 | 100%
tests/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/test_allocate_stat_checked.py | 65 | 0 | 0 | 0 | 0 | 100%
tests/test_complex_delc_has_dp.py | 47 | 3 | 0 | 0 | 0 | 94%
tests/test_complex_function_has_dp.py | 34 | 0 | 0 | 0 | 0 | 100%
tests/test_identifier.py | 40 | 0 | 0 | 0 | 0 | 100%
tests/test_integer_literal_has_correct_kind.py | 18 | 0 | 0 | 0 | 0 | 100%
tests/test_real_delc_has_dp.py | 67 | 3 | 0 | 0 | 0 | 96%
tests/test_real_literal_has_correct_kind.py | 30 | 0 | 0 | 0 | 0 | 100%
tests/test_trace_entry_exit.py | 97 | 0 | 0 | 0 | 0 | 100%
Total | 977 | 109 | 0 | 194 | 13 | 87%

No items found using the specified filter.